@@ -13,22 +13,21 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
-import PaginatedList
+import github.GithubObject
+import github.PaginatedList
 
-import InputFileContent
-import Gist
-import Repository
-import NamedUser
-import Plan
-import Organization
-import UserKey
-import Issue
-import Event
-import Authorization
+import github.Gist
+import github.Repository
+import github.NamedUser
+import github.Plan
+import github.Organization
+import github.UserKey
+import github.Issue
+import github.Event
+import github.Authorization
 
 
-class AuthenticatedUser(GithubObject.GithubObject):
+class AuthenticatedUser(github.GithubObject.GithubObject):
     @property
     def avatar_url(self):
         self._completeIfNotSet(self._avatar_url)
@@ -165,7 +164,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def add_to_following(self, following):
-        assert isinstance(following, NamedUser.NamedUser), following
+        assert isinstance(following, github.NamedUser.NamedUser), following
         headers, data = self._requester.requestAndCheck(
             "PUT",
             "/user/following/" + following._identity,
@@ -174,7 +173,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def add_to_starred(self, starred):
-        assert isinstance(starred, Repository.Repository), starred
+        assert isinstance(starred, github.Repository.Repository), starred
         headers, data = self._requester.requestAndCheck(
             "PUT",
             "/user/starred/" + starred._identity,
@@ -183,7 +182,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def add_to_subscriptions(self, subscription):
-        assert isinstance(subscription, Repository.Repository), subscription
+        assert isinstance(subscription, github.Repository.Repository), subscription
         headers, data = self._requester.requestAndCheck(
             "PUT",
             "/user/subscriptions/" + subscription._identity,
@@ -192,7 +191,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def add_to_watched(self, watched):
-        assert isinstance(watched, Repository.Repository), watched
+        assert isinstance(watched, github.Repository.Repository), watched
         headers, data = self._requester.requestAndCheck(
             "PUT",
             "/user/watched/" + watched._identity,
@@ -200,44 +199,50 @@ class AuthenticatedUser(GithubObject.GithubObject):
             None
         )
 
-    def create_authorization(self, scopes=GithubObject.NotSet, note=GithubObject.NotSet, note_url=GithubObject.NotSet):
-        assert scopes is GithubObject.NotSet or all(isinstance(element, (str, unicode)) for element in scopes), scopes
-        assert note is GithubObject.NotSet or isinstance(note, (str, unicode)), note
-        assert note_url is GithubObject.NotSet or isinstance(note_url, (str, unicode)), note_url
+    def create_authorization(self, scopes=github.GithubObject.NotSet, note=github.GithubObject.NotSet, note_url=github.GithubObject.NotSet, client_id=github.GithubObject.NotSet, client_secret=github.GithubObject.NotSet):
+        assert scopes is github.GithubObject.NotSet or all(isinstance(element, (str, unicode)) for element in scopes), scopes
+        assert note is github.GithubObject.NotSet or isinstance(note, (str, unicode)), note
+        assert note_url is github.GithubObject.NotSet or isinstance(note_url, (str, unicode)), note_url
+        assert client_id is github.GithubObject.NotSet or isinstance(client_id, (str, unicode)), client_id
+        assert client_secret is github.GithubObject.NotSet or isinstance(client_secret, (str, unicode)), client_secret
         post_parameters = dict()
-        if scopes is not GithubObject.NotSet:
+        if scopes is not github.GithubObject.NotSet:
             post_parameters["scopes"] = scopes
-        if note is not GithubObject.NotSet:
+        if note is not github.GithubObject.NotSet:
             post_parameters["note"] = note
-        if note_url is not GithubObject.NotSet:
+        if note_url is not github.GithubObject.NotSet:
             post_parameters["note_url"] = note_url
+        if client_id is not github.GithubObject.NotSet:
+            post_parameters["client_id"] = client_id
+        if client_secret is not github.GithubObject.NotSet:
+            post_parameters["client_secret"] = client_secret
         headers, data = self._requester.requestAndCheck(
             "POST",
             "/authorizations",
             None,
             post_parameters
         )
-        return Authorization.Authorization(self._requester, data, completed=True)
+        return github.Authorization.Authorization(self._requester, data, completed=True)
 
     def create_fork(self, repo):
-        assert isinstance(repo, Repository.Repository), repo
+        assert isinstance(repo, github.Repository.Repository), repo
         headers, data = self._requester.requestAndCheck(
             "POST",
             "/repos/" + repo.owner.login + "/" + repo.name + "/forks",
             None,
             None
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def create_gist(self, public, files, description=GithubObject.NotSet):
+    def create_gist(self, public, files, description=github.GithubObject.NotSet):
         assert isinstance(public, bool), public
-        assert all(isinstance(element, InputFileContent.InputFileContent) for element in files.itervalues()), files
-        assert description is GithubObject.NotSet or isinstance(description, (str, unicode)), description
+        assert all(isinstance(element, github.InputFileContent) for element in files.itervalues()), files
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
         post_parameters = {
             "public": public,
             "files": dict((key, value._identity) for key, value in files.iteritems()),
         }
-        if description is not GithubObject.NotSet:
+        if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -245,7 +250,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return Gist.Gist(self._requester, data, completed=True)
+        return github.Gist.Gist(self._requester, data, completed=True)
 
     def create_key(self, title, key):
         assert isinstance(title, (str, unicode)), title
@@ -260,36 +265,36 @@ class AuthenticatedUser(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return UserKey.UserKey(self._requester, data, completed=True)
+        return github.UserKey.UserKey(self._requester, data, completed=True)
 
-    def create_repo(self, name, description=GithubObject.NotSet, homepage=GithubObject.NotSet, private=GithubObject.NotSet, has_issues=GithubObject.NotSet, has_wiki=GithubObject.NotSet, has_downloads=GithubObject.NotSet, auto_init=GithubObject.NotSet, gitignore_template=GithubObject.NotSet):
+    def create_repo(self, name, description=github.GithubObject.NotSet, homepage=github.GithubObject.NotSet, private=github.GithubObject.NotSet, has_issues=github.GithubObject.NotSet, has_wiki=github.GithubObject.NotSet, has_downloads=github.GithubObject.NotSet, auto_init=github.GithubObject.NotSet, gitignore_template=github.GithubObject.NotSet):
         assert isinstance(name, (str, unicode)), name
-        assert description is GithubObject.NotSet or isinstance(description, (str, unicode)), description
-        assert homepage is GithubObject.NotSet or isinstance(homepage, (str, unicode)), homepage
-        assert private is GithubObject.NotSet or isinstance(private, bool), private
-        assert has_issues is GithubObject.NotSet or isinstance(has_issues, bool), has_issues
-        assert has_wiki is GithubObject.NotSet or isinstance(has_wiki, bool), has_wiki
-        assert has_downloads is GithubObject.NotSet or isinstance(has_downloads, bool), has_downloads
-        assert auto_init is GithubObject.NotSet or isinstance(auto_init, bool), auto_init
-        assert gitignore_template is GithubObject.NotSet or isinstance(gitignore_template, (str, unicode)), gitignore_template
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
+        assert homepage is github.GithubObject.NotSet or isinstance(homepage, (str, unicode)), homepage
+        assert private is github.GithubObject.NotSet or isinstance(private, bool), private
+        assert has_issues is github.GithubObject.NotSet or isinstance(has_issues, bool), has_issues
+        assert has_wiki is github.GithubObject.NotSet or isinstance(has_wiki, bool), has_wiki
+        assert has_downloads is github.GithubObject.NotSet or isinstance(has_downloads, bool), has_downloads
+        assert auto_init is github.GithubObject.NotSet or isinstance(auto_init, bool), auto_init
+        assert gitignore_template is github.GithubObject.NotSet or isinstance(gitignore_template, (str, unicode)), gitignore_template
         post_parameters = {
             "name": name,
         }
-        if description is not GithubObject.NotSet:
+        if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
-        if homepage is not GithubObject.NotSet:
+        if homepage is not github.GithubObject.NotSet:
             post_parameters["homepage"] = homepage
-        if private is not GithubObject.NotSet:
+        if private is not github.GithubObject.NotSet:
             post_parameters["private"] = private
-        if has_issues is not GithubObject.NotSet:
+        if has_issues is not github.GithubObject.NotSet:
             post_parameters["has_issues"] = has_issues
-        if has_wiki is not GithubObject.NotSet:
+        if has_wiki is not github.GithubObject.NotSet:
             post_parameters["has_wiki"] = has_wiki
-        if has_downloads is not GithubObject.NotSet:
+        if has_downloads is not github.GithubObject.NotSet:
             post_parameters["has_downloads"] = has_downloads
-        if auto_init is not GithubObject.NotSet:
+        if auto_init is not github.GithubObject.NotSet:
             post_parameters["auto_init"] = auto_init
-        if gitignore_template is not GithubObject.NotSet:
+        if gitignore_template is not github.GithubObject.NotSet:
             post_parameters["gitignore_template"] = gitignore_template
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -297,30 +302,30 @@ class AuthenticatedUser(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def edit(self, name=GithubObject.NotSet, email=GithubObject.NotSet, blog=GithubObject.NotSet, company=GithubObject.NotSet, location=GithubObject.NotSet, hireable=GithubObject.NotSet, bio=GithubObject.NotSet):
-        assert name is GithubObject.NotSet or isinstance(name, (str, unicode)), name
-        assert email is GithubObject.NotSet or isinstance(email, (str, unicode)), email
-        assert blog is GithubObject.NotSet or isinstance(blog, (str, unicode)), blog
-        assert company is GithubObject.NotSet or isinstance(company, (str, unicode)), company
-        assert location is GithubObject.NotSet or isinstance(location, (str, unicode)), location
-        assert hireable is GithubObject.NotSet or isinstance(hireable, bool), hireable
-        assert bio is GithubObject.NotSet or isinstance(bio, (str, unicode)), bio
+    def edit(self, name=github.GithubObject.NotSet, email=github.GithubObject.NotSet, blog=github.GithubObject.NotSet, company=github.GithubObject.NotSet, location=github.GithubObject.NotSet, hireable=github.GithubObject.NotSet, bio=github.GithubObject.NotSet):
+        assert name is github.GithubObject.NotSet or isinstance(name, (str, unicode)), name
+        assert email is github.GithubObject.NotSet or isinstance(email, (str, unicode)), email
+        assert blog is github.GithubObject.NotSet or isinstance(blog, (str, unicode)), blog
+        assert company is github.GithubObject.NotSet or isinstance(company, (str, unicode)), company
+        assert location is github.GithubObject.NotSet or isinstance(location, (str, unicode)), location
+        assert hireable is github.GithubObject.NotSet or isinstance(hireable, bool), hireable
+        assert bio is github.GithubObject.NotSet or isinstance(bio, (str, unicode)), bio
         post_parameters = dict()
-        if name is not GithubObject.NotSet:
+        if name is not github.GithubObject.NotSet:
             post_parameters["name"] = name
-        if email is not GithubObject.NotSet:
+        if email is not github.GithubObject.NotSet:
             post_parameters["email"] = email
-        if blog is not GithubObject.NotSet:
+        if blog is not github.GithubObject.NotSet:
             post_parameters["blog"] = blog
-        if company is not GithubObject.NotSet:
+        if company is not github.GithubObject.NotSet:
             post_parameters["company"] = company
-        if location is not GithubObject.NotSet:
+        if location is not github.GithubObject.NotSet:
             post_parameters["location"] = location
-        if hireable is not GithubObject.NotSet:
+        if hireable is not github.GithubObject.NotSet:
             post_parameters["hireable"] = hireable
-        if bio is not GithubObject.NotSet:
+        if bio is not github.GithubObject.NotSet:
             post_parameters["bio"] = bio
         headers, data = self._requester.requestAndCheck(
             "PATCH",
@@ -331,18 +336,18 @@ class AuthenticatedUser(GithubObject.GithubObject):
         self._useAttributes(data)
 
     def get_authorization(self, id):
-        assert isinstance(id, int), id
+        assert isinstance(id, (int, long)), id
         headers, data = self._requester.requestAndCheck(
             "GET",
             "/authorizations/" + str(id),
             None,
             None
         )
-        return Authorization.Authorization(self._requester, data, completed=True)
+        return github.Authorization.Authorization(self._requester, data, completed=True)
 
     def get_authorizations(self):
-        return PaginatedList.PaginatedList(
-            Authorization.Authorization,
+        return github.PaginatedList.PaginatedList(
+            github.Authorization.Authorization,
             self._requester,
             "/authorizations",
             None
@@ -358,75 +363,75 @@ class AuthenticatedUser(GithubObject.GithubObject):
         return data
 
     def get_events(self):
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             "/events",
             None
         )
 
     def get_followers(self):
-        return PaginatedList.PaginatedList(
-            NamedUser.NamedUser,
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
             self._requester,
             "/user/followers",
             None
         )
 
     def get_following(self):
-        return PaginatedList.PaginatedList(
-            NamedUser.NamedUser,
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
             self._requester,
             "/user/following",
             None
         )
 
     def get_gists(self):
-        return PaginatedList.PaginatedList(
-            Gist.Gist,
+        return github.PaginatedList.PaginatedList(
+            github.Gist.Gist,
             self._requester,
             "/gists",
             None
         )
 
     def get_issues(self):
-        return PaginatedList.PaginatedList(
-            Issue.Issue,
+        return github.PaginatedList.PaginatedList(
+            github.Issue.Issue,
             self._requester,
             "/issues",
             None
         )
 
     def get_key(self, id):
-        assert isinstance(id, int), id
+        assert isinstance(id, (int, long)), id
         headers, data = self._requester.requestAndCheck(
             "GET",
             "/user/keys/" + str(id),
             None,
             None
         )
-        return UserKey.UserKey(self._requester, data, completed=True)
+        return github.UserKey.UserKey(self._requester, data, completed=True)
 
     def get_keys(self):
-        return PaginatedList.PaginatedList(
-            UserKey.UserKey,
+        return github.PaginatedList.PaginatedList(
+            github.UserKey.UserKey,
             self._requester,
             "/user/keys",
             None
         )
 
     def get_organization_events(self, org):
-        assert isinstance(org, Organization.Organization), org
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        assert isinstance(org, github.Organization.Organization), org
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             "/users/" + self.login + "/events/orgs/" + org.login,
             None
         )
 
     def get_orgs(self):
-        return PaginatedList.PaginatedList(
-            Organization.Organization,
+        return github.PaginatedList.PaginatedList(
+            github.Organization.Organization,
             self._requester,
             "/user/orgs",
             None
@@ -440,60 +445,60 @@ class AuthenticatedUser(GithubObject.GithubObject):
             None,
             None
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def get_repos(self, type=GithubObject.NotSet, sort=GithubObject.NotSet, direction=GithubObject.NotSet):
-        assert type is GithubObject.NotSet or isinstance(type, (str, unicode)), type
-        assert sort is GithubObject.NotSet or isinstance(sort, (str, unicode)), sort
-        assert direction is GithubObject.NotSet or isinstance(direction, (str, unicode)), direction
+    def get_repos(self, type=github.GithubObject.NotSet, sort=github.GithubObject.NotSet, direction=github.GithubObject.NotSet):
+        assert type is github.GithubObject.NotSet or isinstance(type, (str, unicode)), type
+        assert sort is github.GithubObject.NotSet or isinstance(sort, (str, unicode)), sort
+        assert direction is github.GithubObject.NotSet or isinstance(direction, (str, unicode)), direction
         url_parameters = dict()
-        if type is not GithubObject.NotSet:
+        if type is not github.GithubObject.NotSet:
             url_parameters["type"] = type
-        if sort is not GithubObject.NotSet:
+        if sort is not github.GithubObject.NotSet:
             url_parameters["sort"] = sort
-        if direction is not GithubObject.NotSet:
+        if direction is not github.GithubObject.NotSet:
             url_parameters["direction"] = direction
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             "/user/repos",
             url_parameters
         )
 
     def get_starred(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             "/user/starred",
             None
         )
 
     def get_starred_gists(self):
-        return PaginatedList.PaginatedList(
-            Gist.Gist,
+        return github.PaginatedList.PaginatedList(
+            github.Gist.Gist,
             self._requester,
             "/gists/starred",
             None
         )
 
     def get_subscriptions(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             "/user/subscriptions",
             None
         )
 
     def get_watched(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             "/user/watched",
             None
         )
 
     def has_in_following(self, following):
-        assert isinstance(following, NamedUser.NamedUser), following
+        assert isinstance(following, github.NamedUser.NamedUser), following
         status, headers, data = self._requester.requestRaw(
             "GET",
             "/user/following/" + following._identity,
@@ -503,7 +508,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         return status == 204
 
     def has_in_starred(self, starred):
-        assert isinstance(starred, Repository.Repository), starred
+        assert isinstance(starred, github.Repository.Repository), starred
         status, headers, data = self._requester.requestRaw(
             "GET",
             "/user/starred/" + starred._identity,
@@ -513,7 +518,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         return status == 204
 
     def has_in_subscriptions(self, subscription):
-        assert isinstance(subscription, Repository.Repository), subscription
+        assert isinstance(subscription, github.Repository.Repository), subscription
         status, headers, data = self._requester.requestRaw(
             "GET",
             "/user/subscriptions/" + subscription._identity,
@@ -523,7 +528,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         return status == 204
 
     def has_in_watched(self, watched):
-        assert isinstance(watched, Repository.Repository), watched
+        assert isinstance(watched, github.Repository.Repository), watched
         status, headers, data = self._requester.requestRaw(
             "GET",
             "/user/watched/" + watched._identity,
@@ -543,7 +548,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def remove_from_following(self, following):
-        assert isinstance(following, NamedUser.NamedUser), following
+        assert isinstance(following, github.NamedUser.NamedUser), following
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             "/user/following/" + following._identity,
@@ -552,7 +557,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def remove_from_starred(self, starred):
-        assert isinstance(starred, Repository.Repository), starred
+        assert isinstance(starred, github.Repository.Repository), starred
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             "/user/starred/" + starred._identity,
@@ -561,7 +566,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def remove_from_subscriptions(self, subscription):
-        assert isinstance(subscription, Repository.Repository), subscription
+        assert isinstance(subscription, github.Repository.Repository), subscription
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             "/user/subscriptions/" + subscription._identity,
@@ -570,7 +575,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def remove_from_watched(self, watched):
-        assert isinstance(watched, Repository.Repository), watched
+        assert isinstance(watched, github.Repository.Repository), watched
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             "/user/watched/" + watched._identity,
@@ -579,31 +584,31 @@ class AuthenticatedUser(GithubObject.GithubObject):
         )
 
     def _initAttributes(self):
-        self._avatar_url = GithubObject.NotSet
-        self._bio = GithubObject.NotSet
-        self._blog = GithubObject.NotSet
-        self._collaborators = GithubObject.NotSet
-        self._company = GithubObject.NotSet
-        self._created_at = GithubObject.NotSet
-        self._disk_usage = GithubObject.NotSet
-        self._email = GithubObject.NotSet
-        self._followers = GithubObject.NotSet
-        self._following = GithubObject.NotSet
-        self._gravatar_id = GithubObject.NotSet
-        self._hireable = GithubObject.NotSet
-        self._html_url = GithubObject.NotSet
-        self._id = GithubObject.NotSet
-        self._location = GithubObject.NotSet
-        self._login = GithubObject.NotSet
-        self._name = GithubObject.NotSet
-        self._owned_private_repos = GithubObject.NotSet
-        self._plan = GithubObject.NotSet
-        self._private_gists = GithubObject.NotSet
-        self._public_gists = GithubObject.NotSet
-        self._public_repos = GithubObject.NotSet
-        self._total_private_repos = GithubObject.NotSet
-        self._type = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._avatar_url = github.GithubObject.NotSet
+        self._bio = github.GithubObject.NotSet
+        self._blog = github.GithubObject.NotSet
+        self._collaborators = github.GithubObject.NotSet
+        self._company = github.GithubObject.NotSet
+        self._created_at = github.GithubObject.NotSet
+        self._disk_usage = github.GithubObject.NotSet
+        self._email = github.GithubObject.NotSet
+        self._followers = github.GithubObject.NotSet
+        self._following = github.GithubObject.NotSet
+        self._gravatar_id = github.GithubObject.NotSet
+        self._hireable = github.GithubObject.NotSet
+        self._html_url = github.GithubObject.NotSet
+        self._id = github.GithubObject.NotSet
+        self._location = github.GithubObject.NotSet
+        self._login = github.GithubObject.NotSet
+        self._name = github.GithubObject.NotSet
+        self._owned_private_repos = github.GithubObject.NotSet
+        self._plan = github.GithubObject.NotSet
+        self._private_gists = github.GithubObject.NotSet
+        self._public_gists = github.GithubObject.NotSet
+        self._public_repos = github.GithubObject.NotSet
+        self._total_private_repos = github.GithubObject.NotSet
+        self._type = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "avatar_url" in attributes:  # pragma no branch
@@ -616,7 +621,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
             assert attributes["blog"] is None or isinstance(attributes["blog"], (str, unicode)), attributes["blog"]
             self._blog = attributes["blog"]
         if "collaborators" in attributes:  # pragma no branch
-            assert attributes["collaborators"] is None or isinstance(attributes["collaborators"], int), attributes["collaborators"]
+            assert attributes["collaborators"] is None or isinstance(attributes["collaborators"], (int, long)), attributes["collaborators"]
             self._collaborators = attributes["collaborators"]
         if "company" in attributes:  # pragma no branch
             assert attributes["company"] is None or isinstance(attributes["company"], (str, unicode)), attributes["company"]
@@ -625,16 +630,16 @@ class AuthenticatedUser(GithubObject.GithubObject):
             assert attributes["created_at"] is None or isinstance(attributes["created_at"], (str, unicode)), attributes["created_at"]
             self._created_at = self._parseDatetime(attributes["created_at"])
         if "disk_usage" in attributes:  # pragma no branch
-            assert attributes["disk_usage"] is None or isinstance(attributes["disk_usage"], int), attributes["disk_usage"]
+            assert attributes["disk_usage"] is None or isinstance(attributes["disk_usage"], (int, long)), attributes["disk_usage"]
             self._disk_usage = attributes["disk_usage"]
         if "email" in attributes:  # pragma no branch
             assert attributes["email"] is None or isinstance(attributes["email"], (str, unicode)), attributes["email"]
             self._email = attributes["email"]
         if "followers" in attributes:  # pragma no branch
-            assert attributes["followers"] is None or isinstance(attributes["followers"], int), attributes["followers"]
+            assert attributes["followers"] is None or isinstance(attributes["followers"], (int, long)), attributes["followers"]
             self._followers = attributes["followers"]
         if "following" in attributes:  # pragma no branch
-            assert attributes["following"] is None or isinstance(attributes["following"], int), attributes["following"]
+            assert attributes["following"] is None or isinstance(attributes["following"], (int, long)), attributes["following"]
             self._following = attributes["following"]
         if "gravatar_id" in attributes:  # pragma no branch
             assert attributes["gravatar_id"] is None or isinstance(attributes["gravatar_id"], (str, unicode)), attributes["gravatar_id"]
@@ -646,7 +651,7 @@ class AuthenticatedUser(GithubObject.GithubObject):
             assert attributes["html_url"] is None or isinstance(attributes["html_url"], (str, unicode)), attributes["html_url"]
             self._html_url = attributes["html_url"]
         if "id" in attributes:  # pragma no branch
-            assert attributes["id"] is None or isinstance(attributes["id"], int), attributes["id"]
+            assert attributes["id"] is None or isinstance(attributes["id"], (int, long)), attributes["id"]
             self._id = attributes["id"]
         if "location" in attributes:  # pragma no branch
             assert attributes["location"] is None or isinstance(attributes["location"], (str, unicode)), attributes["location"]
@@ -658,22 +663,22 @@ class AuthenticatedUser(GithubObject.GithubObject):
             assert attributes["name"] is None or isinstance(attributes["name"], (str, unicode)), attributes["name"]
             self._name = attributes["name"]
         if "owned_private_repos" in attributes:  # pragma no branch
-            assert attributes["owned_private_repos"] is None or isinstance(attributes["owned_private_repos"], int), attributes["owned_private_repos"]
+            assert attributes["owned_private_repos"] is None or isinstance(attributes["owned_private_repos"], (int, long)), attributes["owned_private_repos"]
             self._owned_private_repos = attributes["owned_private_repos"]
         if "plan" in attributes:  # pragma no branch
             assert attributes["plan"] is None or isinstance(attributes["plan"], dict), attributes["plan"]
-            self._plan = None if attributes["plan"] is None else Plan.Plan(self._requester, attributes["plan"], completed=False)
+            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, attributes["plan"], completed=False)
         if "private_gists" in attributes:  # pragma no branch
-            assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], int), attributes["private_gists"]
+            assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], (int, long)), attributes["private_gists"]
             self._private_gists = attributes["private_gists"]
         if "public_gists" in attributes:  # pragma no branch
-            assert attributes["public_gists"] is None or isinstance(attributes["public_gists"], int), attributes["public_gists"]
+            assert attributes["public_gists"] is None or isinstance(attributes["public_gists"], (int, long)), attributes["public_gists"]
             self._public_gists = attributes["public_gists"]
         if "public_repos" in attributes:  # pragma no branch
-            assert attributes["public_repos"] is None or isinstance(attributes["public_repos"], int), attributes["public_repos"]
+            assert attributes["public_repos"] is None or isinstance(attributes["public_repos"], (int, long)), attributes["public_repos"]
             self._public_repos = attributes["public_repos"]
         if "total_private_repos" in attributes:  # pragma no branch
-            assert attributes["total_private_repos"] is None or isinstance(attributes["total_private_repos"], int), attributes["total_private_repos"]
+            assert attributes["total_private_repos"] is None or isinstance(attributes["total_private_repos"], (int, long)), attributes["total_private_repos"]
             self._total_private_repos = attributes["total_private_repos"]
         if "type" in attributes:  # pragma no branch
             assert attributes["type"] is None or isinstance(attributes["type"], (str, unicode)), attributes["type"]
