@@ -13,19 +13,18 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
-import PaginatedList
+import github.GithubObject
+import github.PaginatedList
 
-import GitCommit
-import NamedUser
-import CommitStatus
-import File
-import CommitStats
-import Commit
-import CommitComment
+import github.GitCommit
+import github.NamedUser
+import github.CommitStatus
+import github.File
+import github.CommitStats
+import github.CommitComment
 
 
-class Commit(GithubObject.GithubObject):
+class Commit(github.GithubObject.GithubObject):
     @property
     def author(self):
         self._completeIfNotSet(self._author)
@@ -66,19 +65,19 @@ class Commit(GithubObject.GithubObject):
         self._completeIfNotSet(self._url)
         return self._NoneIfNotSet(self._url)
 
-    def create_comment(self, body, line=GithubObject.NotSet, path=GithubObject.NotSet, position=GithubObject.NotSet):
+    def create_comment(self, body, line=github.GithubObject.NotSet, path=github.GithubObject.NotSet, position=github.GithubObject.NotSet):
         assert isinstance(body, (str, unicode)), body
-        assert line is GithubObject.NotSet or isinstance(line, int), line
-        assert path is GithubObject.NotSet or isinstance(path, (str, unicode)), path
-        assert position is GithubObject.NotSet or isinstance(position, int), position
+        assert line is github.GithubObject.NotSet or isinstance(line, (int, long)), line
+        assert path is github.GithubObject.NotSet or isinstance(path, (str, unicode)), path
+        assert position is github.GithubObject.NotSet or isinstance(position, (int, long)), position
         post_parameters = {
             "body": body,
         }
-        if line is not GithubObject.NotSet:
+        if line is not github.GithubObject.NotSet:
             post_parameters["line"] = line
-        if path is not GithubObject.NotSet:
+        if path is not github.GithubObject.NotSet:
             post_parameters["path"] = path
-        if position is not GithubObject.NotSet:
+        if position is not github.GithubObject.NotSet:
             post_parameters["position"] = position
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -86,18 +85,18 @@ class Commit(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return CommitComment.CommitComment(self._requester, data, completed=True)
+        return github.CommitComment.CommitComment(self._requester, data, completed=True)
 
-    def create_status(self, state, target_url=GithubObject.NotSet, description=GithubObject.NotSet):
+    def create_status(self, state, target_url=github.GithubObject.NotSet, description=github.GithubObject.NotSet):
         assert isinstance(state, (str, unicode)), state
-        assert target_url is GithubObject.NotSet or isinstance(target_url, (str, unicode)), target_url
-        assert description is GithubObject.NotSet or isinstance(description, (str, unicode)), description
+        assert target_url is github.GithubObject.NotSet or isinstance(target_url, (str, unicode)), target_url
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
         post_parameters = {
             "state": state,
         }
-        if target_url is not GithubObject.NotSet:
+        if target_url is not github.GithubObject.NotSet:
             post_parameters["target_url"] = target_url
-        if description is not GithubObject.NotSet:
+        if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -105,19 +104,19 @@ class Commit(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return CommitStatus.CommitStatus(self._requester, data, completed=True)
+        return github.CommitStatus.CommitStatus(self._requester, data, completed=True)
 
     def get_comments(self):
-        return PaginatedList.PaginatedList(
-            CommitComment.CommitComment,
+        return github.PaginatedList.PaginatedList(
+            github.CommitComment.CommitComment,
             self._requester,
             self.url + "/comments",
             None
         )
 
     def get_statuses(self):
-        return PaginatedList.PaginatedList(
-            CommitStatus.CommitStatus,
+        return github.PaginatedList.PaginatedList(
+            github.CommitStatus.CommitStatus,
             self._requester,
             self._parentUrl(self._parentUrl(self.url)) + "/statuses/" + self.sha,
             None
@@ -128,29 +127,29 @@ class Commit(GithubObject.GithubObject):
         return self.sha
 
     def _initAttributes(self):
-        self._author = GithubObject.NotSet
-        self._commit = GithubObject.NotSet
-        self._committer = GithubObject.NotSet
-        self._files = GithubObject.NotSet
-        self._parents = GithubObject.NotSet
-        self._sha = GithubObject.NotSet
-        self._stats = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._author = github.GithubObject.NotSet
+        self._commit = github.GithubObject.NotSet
+        self._committer = github.GithubObject.NotSet
+        self._files = github.GithubObject.NotSet
+        self._parents = github.GithubObject.NotSet
+        self._sha = github.GithubObject.NotSet
+        self._stats = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "author" in attributes:  # pragma no branch
             assert attributes["author"] is None or isinstance(attributes["author"], dict), attributes["author"]
-            self._author = None if attributes["author"] is None else NamedUser.NamedUser(self._requester, attributes["author"], completed=False)
+            self._author = None if attributes["author"] is None else github.NamedUser.NamedUser(self._requester, attributes["author"], completed=False)
         if "commit" in attributes:  # pragma no branch
             assert attributes["commit"] is None or isinstance(attributes["commit"], dict), attributes["commit"]
-            self._commit = None if attributes["commit"] is None else GitCommit.GitCommit(self._requester, attributes["commit"], completed=False)
+            self._commit = None if attributes["commit"] is None else github.GitCommit.GitCommit(self._requester, attributes["commit"], completed=False)
         if "committer" in attributes:  # pragma no branch
             assert attributes["committer"] is None or isinstance(attributes["committer"], dict), attributes["committer"]
-            self._committer = None if attributes["committer"] is None else NamedUser.NamedUser(self._requester, attributes["committer"], completed=False)
+            self._committer = None if attributes["committer"] is None else github.NamedUser.NamedUser(self._requester, attributes["committer"], completed=False)
         if "files" in attributes:  # pragma no branch
             assert attributes["files"] is None or all(isinstance(element, dict) for element in attributes["files"]), attributes["files"]
             self._files = None if attributes["files"] is None else [
-                File.File(self._requester, element, completed=False)
+                github.File.File(self._requester, element, completed=False)
                 for element in attributes["files"]
             ]
         if "parents" in attributes:  # pragma no branch
@@ -164,7 +163,7 @@ class Commit(GithubObject.GithubObject):
             self._sha = attributes["sha"]
         if "stats" in attributes:  # pragma no branch
             assert attributes["stats"] is None or isinstance(attributes["stats"], dict), attributes["stats"]
-            self._stats = None if attributes["stats"] is None else CommitStats.CommitStats(self._requester, attributes["stats"], completed=False)
+            self._stats = None if attributes["stats"] is None else github.CommitStats.CommitStats(self._requester, attributes["stats"], completed=False)
         if "url" in attributes:  # pragma no branch
             assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
             self._url = attributes["url"]
