@@ -20,11 +20,12 @@ import AuthenticatedUser
 import NamedUser
 import Organization
 import Gist
-import PaginatedList
+import github.PaginatedList
 import Repository
 import Legacy
-import GithubObject
+import github.GithubObject
 import HookDescription
+import GitignoreTemplate
 
 
 DEFAULT_BASE_URL = "https://api.github.com"
@@ -47,9 +48,9 @@ class Github(object):
     def rate_limiting(self):
         return self.__requester.rate_limiting
 
-    def get_user(self, login=GithubObject.NotSet):
-        assert login is GithubObject.NotSet or isinstance(login, (str, unicode)), login
-        if login is GithubObject.NotSet:
+    def get_user(self, login=github.GithubObject.NotSet):
+        assert login is github.GithubObject.NotSet or isinstance(login, (str, unicode)), login
+        if login is github.GithubObject.NotSet:
             return AuthenticatedUser.AuthenticatedUser(self.__requester, {"url": "/user"}, completed=False)
         else:
             headers, data = self.__requester.requestAndCheck(
@@ -58,7 +59,7 @@ class Github(object):
                 None,
                 None
             )
-            return NamedUser.NamedUser(self.__requester, data, completed=True)
+            return github.NamedUser.NamedUser(self.__requester, data, completed=True)
 
     def get_organization(self, login):
         assert isinstance(login, (str, unicode)), login
@@ -68,7 +69,17 @@ class Github(object):
             None,
             None
         )
-        return Organization.Organization(self.__requester, data, completed=True)
+        return github.Organization.Organization(self.__requester, data, completed=True)
+
+    def get_repo(self, full_name):
+        assert isinstance(full_name, (str, unicode)), full_name
+        headers, data = self.__requester.requestAndCheck(
+            "GET",
+            "/repos/" + full_name,
+            None,
+            None
+        )
+        return Repository.Repository(self.__requester, data, completed=True)
 
     def get_gist(self, id):
         assert isinstance(id, (str, unicode)), id
@@ -78,27 +89,27 @@ class Github(object):
             None,
             None
         )
-        return Gist.Gist(self.__requester, data, completed=True)
+        return github.Gist.Gist(self.__requester, data, completed=True)
 
     def get_gists(self):
-        return PaginatedList.PaginatedList(
-            Gist.Gist,
+        return github.PaginatedList.PaginatedList(
+            github.Gist.Gist,
             self.__requester,
             "/gists/public",
             None
         )
 
-    def legacy_search_repos(self, keyword, language=GithubObject.NotSet):
+    def legacy_search_repos(self, keyword, language=github.GithubObject.NotSet):
         assert isinstance(keyword, (str, unicode)), keyword
-        assert language is GithubObject.NotSet or isinstance(language, (str, unicode)), language
-        args = {} if language is GithubObject.NotSet else {"language": language}
+        assert language is github.GithubObject.NotSet or isinstance(language, (str, unicode)), language
+        args = {} if language is github.GithubObject.NotSet else {"language": language}
         return Legacy.PaginatedList(
             "/legacy/repos/search/" + urllib.quote(keyword),
             args,
             self.__requester,
             "repositories",
             Legacy.convertRepo,
-            Repository.Repository,
+            github.Repository.Repository,
         )
 
     def legacy_search_users(self, keyword):
@@ -109,7 +120,7 @@ class Github(object):
             self.__requester,
             "users",
             Legacy.convertUser,
-            NamedUser.NamedUser,
+            github.NamedUser.NamedUser,
         )
 
     def legacy_search_user_by_email(self, email):
@@ -120,15 +131,15 @@ class Github(object):
             None,
             None
         )
-        return NamedUser.NamedUser(self.__requester, Legacy.convertUser(data["user"]), completed=False)
+        return github.NamedUser.NamedUser(self.__requester, Legacy.convertUser(data["user"]), completed=False)
 
-    def render_markdown(self, text, context=GithubObject.NotSet):
+    def render_markdown(self, text, context=github.GithubObject.NotSet):
         assert isinstance(text, (str, unicode)), text
-        assert context is GithubObject.NotSet or isinstance(context, Repository.Repository), context
+        assert context is github.GithubObject.NotSet or isinstance(context, github.Repository.Repository), context
         post_parameters = {
             "text": text
         }
-        if context is not GithubObject.NotSet:
+        if context is not github.GithubObject.NotSet:
             post_parameters["mode"] = "gfm"
             post_parameters["context"] = context._identity
         status, headers, data = self.__requester.requestRaw(
@@ -147,3 +158,22 @@ class Github(object):
             None
         )
         return [HookDescription.HookDescription(self.__requester, attributes, completed=True) for attributes in data]
+
+    def get_gitignore_templates(self):
+        headers, data = self.__requester.requestAndCheck(
+            "GET",
+            "/gitignore/templates",
+            None,
+            None
+        )
+        return data
+
+    def get_gitignore_template(self, name):
+        assert isinstance(name, (str, unicode)), name
+        headers, attributes = self.__requester.requestAndCheck(
+            "GET",
+            "/gitignore/templates/" + name,
+            None,
+            None
+        )
+        return GitignoreTemplate.GitignoreTemplate(self.__requester, attributes, completed=True)
