@@ -13,13 +13,13 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
+import github.GithubObject
 
-import Issue
-import NamedUser
+import github.Issue
+import github.NamedUser
 
 
-class IssueEvent(GithubObject.GithubObject):
+class IssueEvent(github.GithubObject.GithubObject):
     @property
     def actor(self):
         self._completeIfNotSet(self._actor)
@@ -56,18 +56,18 @@ class IssueEvent(GithubObject.GithubObject):
         return self._NoneIfNotSet(self._url)
 
     def _initAttributes(self):
-        self._actor = GithubObject.NotSet
-        self._commit_id = GithubObject.NotSet
-        self._created_at = GithubObject.NotSet
-        self._event = GithubObject.NotSet
-        self._id = GithubObject.NotSet
-        self._issue = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._actor = github.GithubObject.NotSet
+        self._commit_id = github.GithubObject.NotSet
+        self._created_at = github.GithubObject.NotSet
+        self._event = github.GithubObject.NotSet
+        self._id = github.GithubObject.NotSet
+        self._issue = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "actor" in attributes:  # pragma no branch
             assert attributes["actor"] is None or isinstance(attributes["actor"], dict), attributes["actor"]
-            self._actor = None if attributes["actor"] is None else NamedUser.NamedUser(self._requester, attributes["actor"], completed=False)
+            self._actor = None if attributes["actor"] is None else github.NamedUser.NamedUser(self._requester, attributes["actor"], completed=False)
         if "commit_id" in attributes:  # pragma no branch
             assert attributes["commit_id"] is None or isinstance(attributes["commit_id"], (str, unicode)), attributes["commit_id"]
             self._commit_id = attributes["commit_id"]
@@ -78,11 +78,11 @@ class IssueEvent(GithubObject.GithubObject):
             assert attributes["event"] is None or isinstance(attributes["event"], (str, unicode)), attributes["event"]
             self._event = attributes["event"]
         if "id" in attributes:  # pragma no branch
-            assert attributes["id"] is None or isinstance(attributes["id"], int), attributes["id"]
+            assert attributes["id"] is None or isinstance(attributes["id"], (int, long)), attributes["id"]
             self._id = attributes["id"]
         if "issue" in attributes:  # pragma no branch
             assert attributes["issue"] is None or isinstance(attributes["issue"], dict), attributes["issue"]
-            self._issue = None if attributes["issue"] is None else Issue.Issue(self._requester, attributes["issue"], completed=False)
+            self._issue = None if attributes["issue"] is None else github.Issue.Issue(self._requester, attributes["issue"], completed=False)
         if "url" in attributes:  # pragma no branch
             assert attributes["url"] is None or isinstance(attributes["url"], (str, unicode)), attributes["url"]
             self._url = attributes["url"]
