@@ -13,19 +13,18 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
-import PaginatedList
+import github.GithubObject
+import github.PaginatedList
 
-import Gist
-import Repository
-import NamedUser
-import Plan
-import Organization
-import InputFileContent
-import Event
+import github.Gist
+import github.Repository
+import github.NamedUser
+import github.Plan
+import github.Organization
+import github.Event
 
 
-class NamedUser(GithubObject.GithubObject):
+class NamedUser(github.GithubObject.GithubObject):
     @property
     def avatar_url(self):
         self._completeIfNotSet(self._avatar_url)
@@ -156,15 +155,15 @@ class NamedUser(GithubObject.GithubObject):
         self._completeIfNotSet(self._url)
         return self._NoneIfNotSet(self._url)
 
-    def create_gist(self, public, files, description=GithubObject.NotSet):
+    def create_gist(self, public, files, description=github.GithubObject.NotSet):
         assert isinstance(public, bool), public
-        assert all(isinstance(element, InputFileContent.InputFileContent) for element in files.itervalues()), files
-        assert description is GithubObject.NotSet or isinstance(description, (str, unicode)), description
+        assert all(isinstance(element, github.InputFileContent) for element in files.itervalues()), files
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
         post_parameters = {
             "public": public,
             "files": dict((key, value._identity) for key, value in files.iteritems()),
         }
-        if description is not GithubObject.NotSet:
+        if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -172,18 +171,18 @@ class NamedUser(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return Gist.Gist(self._requester, data, completed=True)
+        return github.Gist.Gist(self._requester, data, completed=True)
 
     def get_events(self):
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             self.url + "/events",
             None
         )
 
     def get_followers(self):
-        return PaginatedList.PaginatedList(
+        return github.PaginatedList.PaginatedList(
             NamedUser,
             self._requester,
             self.url + "/followers",
@@ -191,7 +190,7 @@ class NamedUser(GithubObject.GithubObject):
         )
 
     def get_following(self):
-        return PaginatedList.PaginatedList(
+        return github.PaginatedList.PaginatedList(
             NamedUser,
             self._requester,
             self.url + "/following",
@@ -199,40 +198,40 @@ class NamedUser(GithubObject.GithubObject):
         )
 
     def get_gists(self):
-        return PaginatedList.PaginatedList(
-            Gist.Gist,
+        return github.PaginatedList.PaginatedList(
+            github.Gist.Gist,
             self._requester,
             self.url + "/gists",
             None
         )
 
     def get_orgs(self):
-        return PaginatedList.PaginatedList(
-            Organization.Organization,
+        return github.PaginatedList.PaginatedList(
+            github.Organization.Organization,
             self._requester,
             self.url + "/orgs",
             None
         )
 
     def get_public_events(self):
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             self.url + "/events/public",
             None
         )
 
     def get_public_received_events(self):
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             self.url + "/received_events/public",
             None
         )
 
     def get_received_events(self):
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             self.url + "/received_events",
             None
@@ -246,39 +245,39 @@ class NamedUser(GithubObject.GithubObject):
             None,
             None
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def get_repos(self, type=GithubObject.NotSet):
-        assert type is GithubObject.NotSet or isinstance(type, (str, unicode)), type
+    def get_repos(self, type=github.GithubObject.NotSet):
+        assert type is github.GithubObject.NotSet or isinstance(type, (str, unicode)), type
         url_parameters = dict()
-        if type is not GithubObject.NotSet:
+        if type is not github.GithubObject.NotSet:
             url_parameters["type"] = type
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             self.url + "/repos",
             url_parameters
         )
 
     def get_starred(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             self.url + "/starred",
             None
         )
 
     def get_subscriptions(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             self.url + "/subscriptions",
             None
         )
 
     def get_watched(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             self.url + "/watched",
             None
@@ -289,32 +288,32 @@ class NamedUser(GithubObject.GithubObject):
         return self.login
 
     def _initAttributes(self):
-        self._avatar_url = GithubObject.NotSet
-        self._bio = GithubObject.NotSet
-        self._blog = GithubObject.NotSet
-        self._collaborators = GithubObject.NotSet
-        self._company = GithubObject.NotSet
-        self._contributions = GithubObject.NotSet
-        self._created_at = GithubObject.NotSet
-        self._disk_usage = GithubObject.NotSet
-        self._email = GithubObject.NotSet
-        self._followers = GithubObject.NotSet
-        self._following = GithubObject.NotSet
-        self._gravatar_id = GithubObject.NotSet
-        self._hireable = GithubObject.NotSet
-        self._html_url = GithubObject.NotSet
-        self._id = GithubObject.NotSet
-        self._location = GithubObject.NotSet
-        self._login = GithubObject.NotSet
-        self._name = GithubObject.NotSet
-        self._owned_private_repos = GithubObject.NotSet
-        self._plan = GithubObject.NotSet
-        self._private_gists = GithubObject.NotSet
-        self._public_gists = GithubObject.NotSet
-        self._public_repos = GithubObject.NotSet
-        self._total_private_repos = GithubObject.NotSet
-        self._type = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._avatar_url = github.GithubObject.NotSet
+        self._bio = github.GithubObject.NotSet
+        self._blog = github.GithubObject.NotSet
+        self._collaborators = github.GithubObject.NotSet
+        self._company = github.GithubObject.NotSet
+        self._contributions = github.GithubObject.NotSet
+        self._created_at = github.GithubObject.NotSet
+        self._disk_usage = github.GithubObject.NotSet
+        self._email = github.GithubObject.NotSet
+        self._followers = github.GithubObject.NotSet
+        self._following = github.GithubObject.NotSet
+        self._gravatar_id = github.GithubObject.NotSet
+        self._hireable = github.GithubObject.NotSet
+        self._html_url = github.GithubObject.NotSet
+        self._id = github.GithubObject.NotSet
+        self._location = github.GithubObject.NotSet
+        self._login = github.GithubObject.NotSet
+        self._name = github.GithubObject.NotSet
+        self._owned_private_repos = github.GithubObject.NotSet
+        self._plan = github.GithubObject.NotSet
+        self._private_gists = github.GithubObject.NotSet
+        self._public_gists = github.GithubObject.NotSet
+        self._public_repos = github.GithubObject.NotSet
+        self._total_private_repos = github.GithubObject.NotSet
+        self._type = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "avatar_url" in attributes:  # pragma no branch
@@ -376,7 +375,7 @@ class NamedUser(GithubObject.GithubObject):
             self._owned_private_repos = attributes["owned_private_repos"]
         if "plan" in attributes:  # pragma no branch
             assert attributes["plan"] is None or isinstance(attributes["plan"], dict), attributes["plan"]
-            self._plan = None if attributes["plan"] is None else Plan.Plan(self._requester, attributes["plan"], completed=False)
+            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, attributes["plan"], completed=False)
         if "private_gists" in attributes:  # pragma no branch
             assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], (int, long)), attributes["private_gists"]
             self._private_gists = attributes["private_gists"]
