@@ -13,17 +13,17 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
-import PaginatedList
+import github.GithubObject
+import github.PaginatedList
 
-import Plan
-import Team
-import Event
-import Repository
-import NamedUser
+import github.Plan
+import github.Team
+import github.Event
+import github.Repository
+import github.NamedUser
 
 
-class Organization(GithubObject.GithubObject):
+class Organization(github.GithubObject.GithubObject):
     @property
     def avatar_url(self):
         self._completeIfNotSet(self._avatar_url)
@@ -145,7 +145,7 @@ class Organization(GithubObject.GithubObject):
         return self._NoneIfNotSet(self._url)
 
     def add_to_public_members(self, public_member):
-        assert isinstance(public_member, NamedUser.NamedUser), public_member
+        assert isinstance(public_member, github.NamedUser.NamedUser), public_member
         headers, data = self._requester.requestAndCheck(
             "PUT",
             self.url + "/public_members/" + public_member._identity,
@@ -154,7 +154,7 @@ class Organization(GithubObject.GithubObject):
         )
 
     def create_fork(self, repo):
-        assert isinstance(repo, Repository.Repository), repo
+        assert isinstance(repo, github.Repository.Repository), repo
         url_parameters = {
             "org": self.login,
         }
@@ -164,39 +164,39 @@ class Organization(GithubObject.GithubObject):
             url_parameters,
             None
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def create_repo(self, name, description=GithubObject.NotSet, homepage=GithubObject.NotSet, private=GithubObject.NotSet, has_issues=GithubObject.NotSet, has_wiki=GithubObject.NotSet, has_downloads=GithubObject.NotSet, team_id=GithubObject.NotSet, auto_init=GithubObject.NotSet, gitignore_template=GithubObject.NotSet):
+    def create_repo(self, name, description=github.GithubObject.NotSet, homepage=github.GithubObject.NotSet, private=github.GithubObject.NotSet, has_issues=github.GithubObject.NotSet, has_wiki=github.GithubObject.NotSet, has_downloads=github.GithubObject.NotSet, team_id=github.GithubObject.NotSet, auto_init=github.GithubObject.NotSet, gitignore_template=github.GithubObject.NotSet):
         assert isinstance(name, (str, unicode)), name
-        assert description is GithubObject.NotSet or isinstance(description, (str, unicode)), description
-        assert homepage is GithubObject.NotSet or isinstance(homepage, (str, unicode)), homepage
-        assert private is GithubObject.NotSet or isinstance(private, bool), private
-        assert has_issues is GithubObject.NotSet or isinstance(has_issues, bool), has_issues
-        assert has_wiki is GithubObject.NotSet or isinstance(has_wiki, bool), has_wiki
-        assert has_downloads is GithubObject.NotSet or isinstance(has_downloads, bool), has_downloads
-        assert team_id is GithubObject.NotSet or isinstance(team_id, Team.Team), team_id
-        assert auto_init is GithubObject.NotSet or isinstance(auto_init, bool), auto_init
-        assert gitignore_template is GithubObject.NotSet or isinstance(gitignore_template, (str, unicode)), gitignore_template
+        assert description is github.GithubObject.NotSet or isinstance(description, (str, unicode)), description
+        assert homepage is github.GithubObject.NotSet or isinstance(homepage, (str, unicode)), homepage
+        assert private is github.GithubObject.NotSet or isinstance(private, bool), private
+        assert has_issues is github.GithubObject.NotSet or isinstance(has_issues, bool), has_issues
+        assert has_wiki is github.GithubObject.NotSet or isinstance(has_wiki, bool), has_wiki
+        assert has_downloads is github.GithubObject.NotSet or isinstance(has_downloads, bool), has_downloads
+        assert team_id is github.GithubObject.NotSet or isinstance(team_id, github.Team.Team), team_id
+        assert auto_init is github.GithubObject.NotSet or isinstance(auto_init, bool), auto_init
+        assert gitignore_template is github.GithubObject.NotSet or isinstance(gitignore_template, (str, unicode)), gitignore_template
         post_parameters = {
             "name": name,
         }
-        if description is not GithubObject.NotSet:
+        if description is not github.GithubObject.NotSet:
             post_parameters["description"] = description
-        if homepage is not GithubObject.NotSet:
+        if homepage is not github.GithubObject.NotSet:
             post_parameters["homepage"] = homepage
-        if private is not GithubObject.NotSet:
+        if private is not github.GithubObject.NotSet:
             post_parameters["private"] = private
-        if has_issues is not GithubObject.NotSet:
+        if has_issues is not github.GithubObject.NotSet:
             post_parameters["has_issues"] = has_issues
-        if has_wiki is not GithubObject.NotSet:
+        if has_wiki is not github.GithubObject.NotSet:
             post_parameters["has_wiki"] = has_wiki
-        if has_downloads is not GithubObject.NotSet:
+        if has_downloads is not github.GithubObject.NotSet:
             post_parameters["has_downloads"] = has_downloads
-        if team_id is not GithubObject.NotSet:
+        if team_id is not github.GithubObject.NotSet:
             post_parameters["team_id"] = team_id._identity
-        if auto_init is not GithubObject.NotSet:
+        if auto_init is not github.GithubObject.NotSet:
             post_parameters["auto_init"] = auto_init
-        if gitignore_template is not GithubObject.NotSet:
+        if gitignore_template is not github.GithubObject.NotSet:
             post_parameters["gitignore_template"] = gitignore_template
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -204,18 +204,18 @@ class Organization(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def create_team(self, name, repo_names=GithubObject.NotSet, permission=GithubObject.NotSet):
+    def create_team(self, name, repo_names=github.GithubObject.NotSet, permission=github.GithubObject.NotSet):
         assert isinstance(name, (str, unicode)), name
-        assert repo_names is GithubObject.NotSet or all(isinstance(element, Repository.Repository) for element in repo_names), repo_names
-        assert permission is GithubObject.NotSet or isinstance(permission, (str, unicode)), permission
+        assert repo_names is github.GithubObject.NotSet or all(isinstance(element, github.Repository.Repository) for element in repo_names), repo_names
+        assert permission is github.GithubObject.NotSet or isinstance(permission, (str, unicode)), permission
         post_parameters = {
             "name": name,
         }
-        if repo_names is not GithubObject.NotSet:
+        if repo_names is not github.GithubObject.NotSet:
             post_parameters["repo_names"] = [element._identity for element in repo_names]
-        if permission is not GithubObject.NotSet:
+        if permission is not github.GithubObject.NotSet:
             post_parameters["permission"] = permission
         headers, data = self._requester.requestAndCheck(
             "POST",
@@ -223,27 +223,27 @@ class Organization(GithubObject.GithubObject):
             None,
             post_parameters
         )
-        return Team.Team(self._requester, data, completed=True)
+        return github.Team.Team(self._requester, data, completed=True)
 
-    def edit(self, billing_email=GithubObject.NotSet, blog=GithubObject.NotSet, company=GithubObject.NotSet, email=GithubObject.NotSet, location=GithubObject.NotSet, name=GithubObject.NotSet):
-        assert billing_email is GithubObject.NotSet or isinstance(billing_email, (str, unicode)), billing_email
-        assert blog is GithubObject.NotSet or isinstance(blog, (str, unicode)), blog
-        assert company is GithubObject.NotSet or isinstance(company, (str, unicode)), company
-        assert email is GithubObject.NotSet or isinstance(email, (str, unicode)), email
-        assert location is GithubObject.NotSet or isinstance(location, (str, unicode)), location
-        assert name is GithubObject.NotSet or isinstance(name, (str, unicode)), name
+    def edit(self, billing_email=github.GithubObject.NotSet, blog=github.GithubObject.NotSet, company=github.GithubObject.NotSet, email=github.GithubObject.NotSet, location=github.GithubObject.NotSet, name=github.GithubObject.NotSet):
+        assert billing_email is github.GithubObject.NotSet or isinstance(billing_email, (str, unicode)), billing_email
+        assert blog is github.GithubObject.NotSet or isinstance(blog, (str, unicode)), blog
+        assert company is github.GithubObject.NotSet or isinstance(company, (str, unicode)), company
+        assert email is github.GithubObject.NotSet or isinstance(email, (str, unicode)), email
+        assert location is github.GithubObject.NotSet or isinstance(location, (str, unicode)), location
+        assert name is github.GithubObject.NotSet or isinstance(name, (str, unicode)), name
         post_parameters = dict()
-        if billing_email is not GithubObject.NotSet:
+        if billing_email is not github.GithubObject.NotSet:
             post_parameters["billing_email"] = billing_email
-        if blog is not GithubObject.NotSet:
+        if blog is not github.GithubObject.NotSet:
             post_parameters["blog"] = blog
-        if company is not GithubObject.NotSet:
+        if company is not github.GithubObject.NotSet:
             post_parameters["company"] = company
-        if email is not GithubObject.NotSet:
+        if email is not github.GithubObject.NotSet:
             post_parameters["email"] = email
-        if location is not GithubObject.NotSet:
+        if location is not github.GithubObject.NotSet:
             post_parameters["location"] = location
-        if name is not GithubObject.NotSet:
+        if name is not github.GithubObject.NotSet:
             post_parameters["name"] = name
         headers, data = self._requester.requestAndCheck(
             "PATCH",
@@ -254,24 +254,24 @@ class Organization(GithubObject.GithubObject):
         self._useAttributes(data)
 
     def get_events(self):
-        return PaginatedList.PaginatedList(
-            Event.Event,
+        return github.PaginatedList.PaginatedList(
+            github.Event.Event,
             self._requester,
             self.url + "/events",
             None
         )
 
     def get_members(self):
-        return PaginatedList.PaginatedList(
-            NamedUser.NamedUser,
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
             self._requester,
             self.url + "/members",
             None
         )
 
     def get_public_members(self):
-        return PaginatedList.PaginatedList(
-            NamedUser.NamedUser,
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
             self._requester,
             self.url + "/public_members",
             None
@@ -285,15 +285,15 @@ class Organization(GithubObject.GithubObject):
             None,
             None
         )
-        return Repository.Repository(self._requester, data, completed=True)
+        return github.Repository.Repository(self._requester, data, completed=True)
 
-    def get_repos(self, type=GithubObject.NotSet):
-        assert type is GithubObject.NotSet or isinstance(type, (str, unicode)), type
+    def get_repos(self, type=github.GithubObject.NotSet):
+        assert type is github.GithubObject.NotSet or isinstance(type, (str, unicode)), type
         url_parameters = dict()
-        if type is not GithubObject.NotSet:
+        if type is not github.GithubObject.NotSet:
             url_parameters["type"] = type
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             self.url + "/repos",
             url_parameters
@@ -307,18 +307,18 @@ class Organization(GithubObject.GithubObject):
             None,
             None
         )
-        return Team.Team(self._requester, data, completed=True)
+        return github.Team.Team(self._requester, data, completed=True)
 
     def get_teams(self):
-        return PaginatedList.PaginatedList(
-            Team.Team,
+        return github.PaginatedList.PaginatedList(
+            github.Team.Team,
             self._requester,
             self.url + "/teams",
             None
         )
 
     def has_in_members(self, member):
-        assert isinstance(member, NamedUser.NamedUser), member
+        assert isinstance(member, github.NamedUser.NamedUser), member
         status, headers, data = self._requester.requestRaw(
             "GET",
             self.url + "/members/" + member._identity,
@@ -328,7 +328,7 @@ class Organization(GithubObject.GithubObject):
         return status == 204
 
     def has_in_public_members(self, public_member):
-        assert isinstance(public_member, NamedUser.NamedUser), public_member
+        assert isinstance(public_member, github.NamedUser.NamedUser), public_member
         status, headers, data = self._requester.requestRaw(
             "GET",
             self.url + "/public_members/" + public_member._identity,
@@ -338,7 +338,7 @@ class Organization(GithubObject.GithubObject):
         return status == 204
 
     def remove_from_members(self, member):
-        assert isinstance(member, NamedUser.NamedUser), member
+        assert isinstance(member, github.NamedUser.NamedUser), member
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             self.url + "/members/" + member._identity,
@@ -347,7 +347,7 @@ class Organization(GithubObject.GithubObject):
         )
 
     def remove_from_public_members(self, public_member):
-        assert isinstance(public_member, NamedUser.NamedUser), public_member
+        assert isinstance(public_member, github.NamedUser.NamedUser), public_member
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             self.url + "/public_members/" + public_member._identity,
@@ -356,30 +356,30 @@ class Organization(GithubObject.GithubObject):
         )
 
     def _initAttributes(self):
-        self._avatar_url = GithubObject.NotSet
-        self._billing_email = GithubObject.NotSet
-        self._blog = GithubObject.NotSet
-        self._collaborators = GithubObject.NotSet
-        self._company = GithubObject.NotSet
-        self._created_at = GithubObject.NotSet
-        self._disk_usage = GithubObject.NotSet
-        self._email = GithubObject.NotSet
-        self._followers = GithubObject.NotSet
-        self._following = GithubObject.NotSet
-        self._gravatar_id = GithubObject.NotSet
-        self._html_url = GithubObject.NotSet
-        self._id = GithubObject.NotSet
-        self._location = GithubObject.NotSet
-        self._login = GithubObject.NotSet
-        self._name = GithubObject.NotSet
-        self._owned_private_repos = GithubObject.NotSet
-        self._plan = GithubObject.NotSet
-        self._private_gists = GithubObject.NotSet
-        self._public_gists = GithubObject.NotSet
-        self._public_repos = GithubObject.NotSet
-        self._total_private_repos = GithubObject.NotSet
-        self._type = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._avatar_url = github.GithubObject.NotSet
+        self._billing_email = github.GithubObject.NotSet
+        self._blog = github.GithubObject.NotSet
+        self._collaborators = github.GithubObject.NotSet
+        self._company = github.GithubObject.NotSet
+        self._created_at = github.GithubObject.NotSet
+        self._disk_usage = github.GithubObject.NotSet
+        self._email = github.GithubObject.NotSet
+        self._followers = github.GithubObject.NotSet
+        self._following = github.GithubObject.NotSet
+        self._gravatar_id = github.GithubObject.NotSet
+        self._html_url = github.GithubObject.NotSet
+        self._id = github.GithubObject.NotSet
+        self._location = github.GithubObject.NotSet
+        self._login = github.GithubObject.NotSet
+        self._name = github.GithubObject.NotSet
+        self._owned_private_repos = github.GithubObject.NotSet
+        self._plan = github.GithubObject.NotSet
+        self._private_gists = github.GithubObject.NotSet
+        self._public_gists = github.GithubObject.NotSet
+        self._public_repos = github.GithubObject.NotSet
+        self._total_private_repos = github.GithubObject.NotSet
+        self._type = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "avatar_url" in attributes:  # pragma no branch
@@ -435,7 +435,7 @@ class Organization(GithubObject.GithubObject):
             self._owned_private_repos = attributes["owned_private_repos"]
         if "plan" in attributes:  # pragma no branch
             assert attributes["plan"] is None or isinstance(attributes["plan"], dict), attributes["plan"]
-            self._plan = None if attributes["plan"] is None else Plan.Plan(self._requester, attributes["plan"], completed=False)
+            self._plan = None if attributes["plan"] is None else github.Plan.Plan(self._requester, attributes["plan"], completed=False)
         if "private_gists" in attributes:  # pragma no branch
             assert attributes["private_gists"] is None or isinstance(attributes["private_gists"], (int, long)), attributes["private_gists"]
             self._private_gists = attributes["private_gists"]
