@@ -13,7 +13,7 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
+import github.GithubObject
 
 
 class PaginatedListBase:
@@ -22,7 +22,7 @@ class PaginatedListBase:
 
     def __getitem__(self, index):
         assert isinstance(index, (int, slice))
-        if isinstance(index, int):
+        if isinstance(index, (int, long)):
             self.__fetchToIndex(index)
             return self.__elements[index]
         else:
