@@ -13,12 +13,12 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
+import github.GithubObject
 
-import NamedUser
+import github.NamedUser
 
 
-class PullRequestComment(GithubObject.GithubObject):
+class PullRequestComment(github.GithubObject.GithubObject):
     @property
     def body(self):
         self._completeIfNotSet(self._body)
@@ -96,17 +96,17 @@ class PullRequestComment(GithubObject.GithubObject):
         self._useAttributes(data)
 
     def _initAttributes(self):
-        self._body = GithubObject.NotSet
-        self._commit_id = GithubObject.NotSet
-        self._created_at = GithubObject.NotSet
-        self._id = GithubObject.NotSet
-        self._original_commit_id = GithubObject.NotSet
-        self._original_position = GithubObject.NotSet
-        self._path = GithubObject.NotSet
-        self._position = GithubObject.NotSet
-        self._updated_at = GithubObject.NotSet
-        self._url = GithubObject.NotSet
-        self._user = GithubObject.NotSet
+        self._body = github.GithubObject.NotSet
+        self._commit_id = github.GithubObject.NotSet
+        self._created_at = github.GithubObject.NotSet
+        self._id = github.GithubObject.NotSet
+        self._original_commit_id = github.GithubObject.NotSet
+        self._original_position = github.GithubObject.NotSet
+        self._path = github.GithubObject.NotSet
+        self._position = github.GithubObject.NotSet
+        self._updated_at = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
+        self._user = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "body" in attributes:  # pragma no branch
@@ -119,19 +119,19 @@ class PullRequestComment(GithubObject.GithubObject):
             assert attributes["created_at"] is None or isinstance(attributes["created_at"], (str, unicode)), attributes["created_at"]
             self._created_at = self._parseDatetime(attributes["created_at"])
         if "id" in attributes:  # pragma no branch
-            assert attributes["id"] is None or isinstance(attributes["id"], int), attributes["id"]
+            assert attributes["id"] is None or isinstance(attributes["id"], (int, long)), attributes["id"]
             self._id = attributes["id"]
         if "original_commit_id" in attributes:  # pragma no branch
             assert attributes["original_commit_id"] is None or isinstance(attributes["original_commit_id"], (str, unicode)), attributes["original_commit_id"]
             self._original_commit_id = attributes["original_commit_id"]
         if "original_position" in attributes:  # pragma no branch
-            assert attributes["original_position"] is None or isinstance(attributes["original_position"], int), attributes["original_position"]
+            assert attributes["original_position"] is None or isinstance(attributes["original_position"], (int, long)), attributes["original_position"]
             self._original_position = attributes["original_position"]
         if "path" in attributes:  # pragma no branch
             assert attributes["path"] is None or isinstance(attributes["path"], (str, unicode)), attributes["path"]
             self._path = attributes["path"]
         if "position" in attributes:  # pragma no branch
-            assert attributes["position"] is None or isinstance(attributes["position"], int), attributes["position"]
+            assert attributes["position"] is None or isinstance(attributes["position"], (int, long)), attributes["position"]
             self._position = attributes["position"]
         if "updated_at" in attributes:  # pragma no branch
             assert attributes["updated_at"] is None or isinstance(attributes["updated_at"], (str, unicode)), attributes["updated_at"]
@@ -141,4 +141,4 @@ class PullRequestComment(GithubObject.GithubObject):
             self._url = attributes["url"]
         if "user" in attributes:  # pragma no branch
             assert attributes["user"] is None or isinstance(attributes["user"], dict), attributes["user"]
-            self._user = None if attributes["user"] is None else NamedUser.NamedUser(self._requester, attributes["user"], completed=False)
+            self._user = None if attributes["user"] is None else github.NamedUser.NamedUser(self._requester, attributes["user"], completed=False)
