@@ -13,14 +13,14 @@
 
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
-import GithubObject
-import PaginatedList
+import github.GithubObject
+import github.PaginatedList
 
-import Repository
-import NamedUser
+import github.Repository
+import github.NamedUser
 
 
-class Team(GithubObject.GithubObject):
+class Team(github.GithubObject.GithubObject):
     @property
     def id(self):
         self._completeIfNotSet(self._id)
@@ -52,7 +52,7 @@ class Team(GithubObject.GithubObject):
         return self._NoneIfNotSet(self._url)
 
     def add_to_members(self, member):
-        assert isinstance(member, NamedUser.NamedUser), member
+        assert isinstance(member, github.NamedUser.NamedUser), member
         headers, data = self._requester.requestAndCheck(
             "PUT",
             self.url + "/members/" + member._identity,
@@ -61,7 +61,7 @@ class Team(GithubObject.GithubObject):
         )
 
     def add_to_repos(self, repo):
-        assert isinstance(repo, Repository.Repository), repo
+        assert isinstance(repo, github.Repository.Repository), repo
         headers, data = self._requester.requestAndCheck(
             "PUT",
             self.url + "/repos/" + repo._identity,
@@ -77,13 +77,13 @@ class Team(GithubObject.GithubObject):
             None
         )
 
-    def edit(self, name, permission=GithubObject.NotSet):
+    def edit(self, name, permission=github.GithubObject.NotSet):
         assert isinstance(name, (str, unicode)), name
-        assert permission is GithubObject.NotSet or isinstance(permission, (str, unicode)), permission
+        assert permission is github.GithubObject.NotSet or isinstance(permission, (str, unicode)), permission
         post_parameters = {
             "name": name,
         }
-        if permission is not GithubObject.NotSet:
+        if permission is not github.GithubObject.NotSet:
             post_parameters["permission"] = permission
         headers, data = self._requester.requestAndCheck(
             "PATCH",
@@ -94,23 +94,23 @@ class Team(GithubObject.GithubObject):
         self._useAttributes(data)
 
     def get_members(self):
-        return PaginatedList.PaginatedList(
-            NamedUser.NamedUser,
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
             self._requester,
             self.url + "/members",
             None
         )
 
     def get_repos(self):
-        return PaginatedList.PaginatedList(
-            Repository.Repository,
+        return github.PaginatedList.PaginatedList(
+            github.Repository.Repository,
             self._requester,
             self.url + "/repos",
             None
         )
 
     def has_in_members(self, member):
-        assert isinstance(member, NamedUser.NamedUser), member
+        assert isinstance(member, github.NamedUser.NamedUser), member
         status, headers, data = self._requester.requestRaw(
             "GET",
             self.url + "/members/" + member._identity,
@@ -120,7 +120,7 @@ class Team(GithubObject.GithubObject):
         return status == 204
 
     def has_in_repos(self, repo):
-        assert isinstance(repo, Repository.Repository), repo
+        assert isinstance(repo, github.Repository.Repository), repo
         status, headers, data = self._requester.requestRaw(
             "GET",
             self.url + "/repos/" + repo._identity,
@@ -130,7 +130,7 @@ class Team(GithubObject.GithubObject):
         return status == 204
 
     def remove_from_members(self, member):
-        assert isinstance(member, NamedUser.NamedUser), member
+        assert isinstance(member, github.NamedUser.NamedUser), member
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             self.url + "/members/" + member._identity,
@@ -139,7 +139,7 @@ class Team(GithubObject.GithubObject):
         )
 
     def remove_from_repos(self, repo):
-        assert isinstance(repo, Repository.Repository), repo
+        assert isinstance(repo, github.Repository.Repository), repo
         headers, data = self._requester.requestAndCheck(
             "DELETE",
             self.url + "/repos/" + repo._identity,
@@ -152,12 +152,12 @@ class Team(GithubObject.GithubObject):
         return self.id
 
     def _initAttributes(self):
-        self._id = GithubObject.NotSet
-        self._members_count = GithubObject.NotSet
-        self._name = GithubObject.NotSet
-        self._permission = GithubObject.NotSet
-        self._repos_count = GithubObject.NotSet
-        self._url = GithubObject.NotSet
+        self._id = github.GithubObject.NotSet
+        self._members_count = github.GithubObject.NotSet
+        self._name = github.GithubObject.NotSet
+        self._permission = github.GithubObject.NotSet
+        self._repos_count = github.GithubObject.NotSet
+        self._url = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
         if "id" in attributes:  # pragma no branch
